@@ -14,3 +14,11 @@ attr(x[1:3],'foo')        # NULL -- attribute was lost by the subset
 x <- sticky(x)
 attr(x[1:3],'foo')        # 'bar' -- attribute preserved during subset
 
+## ---- results='hide'-----------------------------------------------------
+    df <- data.frame( 
+      sticky   = sticky( structure(1:5, foo="bar") ),
+      nonstick = structure( letters[1:5], foo="bar" )
+    )
+    attr( df[2:3,"nonstick"], 'foo' )  # NULL
+    attr( df[2:3,"sticky"], 'foo' )    # bar
+
